@@ -1,17 +1,21 @@
 package Mojolicious::Plugin::BootstrapHelpers::Helpers {
-$Mojolicious::Plugin::BootstrapHelpers::Helpers::VERSION = '0.016.000';
-use strict;
-    use warnings;
+    use strict;
+    
     use Mojo::Base 'Mojolicious::Plugin';
-
+    
     use List::AllUtils qw/uniq first_index/;
     use Mojo::ByteStream;
     use Mojo::Util 'xml_escape';
     use Scalar::Util 'blessed';
     use String::Trim;
+    use String::Random;
     use Data::Dumper 'Dumper';
     use experimental 'postderef'; # requires 5.20
 
+    our $VERSION = '0.012';
+
+
+
     sub bootstraps_bootstraps {
         my $c = shift;
         my $arg = shift;
@@ -34,9 +38,9 @@ use strict;
 
     sub bootstrap_panel {
         my($c, $title, $callback, $content, $attr) = parse_call(@_);
-
+        
         $attr = add_classes($attr, 'panel', { panel => 'panel-%s', panel_default => 'default'});
-
+        
         my $body = qq{
                 <div class="panel-body">
                     } . contents($callback, $content) . qq{
@@ -51,7 +55,7 @@ use strict;
         my $title = shift;
         my $body = shift;
         my $attr = shift;
-
+        
         my $tag = qq{
             <div class="$attr->{'class'}">
             } . (defined $title ? qq{
@@ -71,7 +75,7 @@ use strict;
         my $callback = ref $_[-1] eq 'CODE' ? pop : undef;
         my $title = scalar @_ % 2 ? shift : undef;
         my $attr = parse_attributes(@_);
-
+        
         $attr = add_classes($attr, 'table', { table => 'table-%s' });
         my $html = htmlify_attrs($attr);
 
@@ -101,11 +105,11 @@ use strict;
 
     sub bootstrap_formgroup {
         my $c = shift;
-        my $title = ref $_[-1] eq 'CODE' ? pop
+        my $title = ref $_[-1] eq 'CODE' ? pop 
                   : scalar @_ % 2        ? shift
                   :                        undef;
         my $attr = parse_attributes(@_);
-
+        
         $attr->{'column_information'} = delete $attr->{'cols'} if ref $attr->{'cols'} eq 'HASH';
 
         my($id, $input) = fix_input($c, $attr);
@@ -131,25 +135,25 @@ use strict;
 
         my @url = shift->@* if ref $_[0] eq 'ARRAY';
         my $attr = parse_attributes(@_);
-
-        my $caret = exists $attr->{'__caret'} && $attr->{'__caret'} ? q{ <span class="caret"></span>} : '';
+        
+        my $caret = exists $attr->{'__caret'} && $attr->{'__caret'} ? q{<span class="caret"></span>} : '';
 
         $attr = add_classes($attr, 'btn', { size => 'btn-%s', button => 'btn-%s', button_default => 'default' });
-        $attr = add_classes($attr, 'active') if $attr->{'__active'};
-        $attr = add_classes($attr, 'block') if $attr->{'__block'};
-        $attr = add_disabled($attr, scalar @url);
         $attr = cleanup_attrs($attr);
 
+
+
         # We have an url
         if(scalar @url) {
             $attr->{'href'} = $c->url_for(@url)->to_string;
-
             my $html = htmlify_attrs($attr);
             return out(qq{<a$html>} . content_single($content) . qq{$caret</a>});
+#            return out(Mojolicious::Plugin::TagHelpers::_tag('a', $attr->%*, $content));
         }
         else {
             my $html = htmlify_attrs($attr);
             return out(qq{<button$html>} . content_single($content) . qq{$caret</button>});
+            #return out(Mojolicious::Plugin::TagHelpers::_tag('button', $attr->%*, $content));
         }
 
     }
@@ -161,46 +165,29 @@ use strict;
 
     sub bootstrap_dropdown {
         my $c = shift;
-
+        my $button_text = iscoderef($_[-1]) ? pop : shift;
         my $attr = parse_attributes(@_);
         my $button_info = delete $attr->{'button'};
-
-        my $button_text = shift $button_info->@*;
-        my $button_attr =  { $button_info->@* };
-
+        my $button_attr = ref $button_info eq 'ARRAY' ? { $button_info->@* } : {};
         my $items_info = delete $attr->{'items'};
 
-        my $ulattr = { __right => exists $attr->{'__right'} ? delete $attr->{'__right'} : 0 };
-        $ulattr = add_classes($ulattr, 'dropdown-menu');
-        $ulattr = add_classes($ulattr, 'dropdown-menu-right') if $ulattr->{'__right'};
-        my $ulhtml = htmlify_attrs($ulattr);
-
         $button_attr = add_classes($button_attr, 'dropdown-toggle');
-        $button_attr->{'data-toggle'} = 'dropdown';
+        $button_attr->{'data'}{'toggle'} = 'dropdown';
         $button_attr->{'type'} = 'button';
-        my $button = bootstrap_button($c, $button_text, $button_attr->%*);
+        #$button_attr->{'id'} ||= String::Random->new->randregex('[a-z]\w{19}'); # when aria
+
+        my $button = bootstrap_button($c, $button_text, $button_attr->%*, __caret => $attr->{'__caret'});
 
         my $menuitems = '';
-
-        ITEM:
         foreach my $item ($items_info->@*) {
-            if(ref $item eq '') {
-                $menuitems .= qq{<li class="dropdown-header">$item</li>};
-            }
-            next ITEM if ref $item ne 'ARRAY';
-            if(!scalar $item->@*) {
-                $menuitems .= q{<li class="divider"></li>} ;
-            }
-            else {
-                $menuitems .= create_dropdown_menuitem($c, $item->@*);
-            }
-
+            $menuitems .= q{<li class="divider"></li>} if $item eq '__divider';
+            $menuitems .= create_dropdown_menuitem($c, $item->@*) if ref $item eq 'ARRAY';
         }
 
         my $dropdown = qq{
             <div class="dropdown">
                 $button
-                <ul$ulhtml>
+                <ul class="dropdown-menu">
                     $menuitems
                 </ul>
             </div>
@@ -210,26 +197,35 @@ use strict;
 
     }
 
-    sub create_dropdown_menuitem {
+    sub create_dropdown_menuitem {use Data::Dumper 'Dumper';
         my $c = shift;
         my $item_text = iscoderef($_[-1]) ? pop : shift;
+        
+        
         my @url = shift->@*;
-
+        
         my $attr = parse_attributes(@_);
+        
         $attr = add_classes($attr, 'menuitem');
-        my $liattr = { __disabled => exists $attr->{'__disabled'} ? delete $attr->{'__disabled'} : 0 };
-        $liattr = add_disabled($liattr, 1);
         $attr->{'tabindex'} ||= -1;
         $attr->{'href'} = $c->url_for(@url)->to_string;
-
+        
         my $html = htmlify_attrs($attr);
-        my $lihtml = htmlify_attrs($liattr);
+        
 
-        my $tag = qq{<li$lihtml><a$html>$item_text</a></li>};
+        my $tag = qq{<li><a$html>$item_text</a></li>};
 
         return out($tag);
     }
 
+    # %= dropdown 'Dropdown', button => [key => 'value'], 
+    #                         items => [
+    #                             item => ['Action', ['url'], %has], 
+    #                             divider,
+    #                             item => []
+    #                         ],
+    #                         caret
+
     sub bootstrap_badge {
         my $c = shift;
         my $content = iscoderef($_[-1]) ? pop : shift;
@@ -266,11 +262,11 @@ use strict;
     sub fix_input {
         my $c = shift;
         my $attr = shift;
-
+        
         my $tagname = (grep { exists $attr->{"${_}_field"} } qw/date datetime month time week color email number range search tel text url password/)[0];
         my $info = $attr->{"${tagname}_field"};
         my $id = shift $info->@*;
-
+        
         # if odd number of elements, the first one is the value (shortcut to avoid having to: value => 'value')
         if($info->@* % 2) {
             push $info->@* => (value => shift $info->@*);
@@ -381,11 +377,11 @@ use strict;
                 push @classes => sprintfify_class($attr, $formatter->{'direction'}, $formatter->{'direction_default'}, _direction_contexts());
             }
         }
-
+       
         $attr->{'class'} = trim join ' ' => uniq sort @classes;
 
         return $attr;
-
+        
     }
 
     sub sprintfify_class {
@@ -403,21 +399,6 @@ use strict;
 
     }
 
-    sub add_disabled {
-        my $attr = shift;
-        my $add_as_class = shift; # if false, add as attribute
-
-        if(exists $attr->{'__disabled'} && $attr->{'__disabled'}) {
-            if($add_as_class) {
-                $attr = add_classes($attr, 'disabled');
-            }
-            else {
-                $attr->{'disabled'} = 'disabled';
-            }
-        }
-        return $attr;
-    }
-
     sub contents {
         my $callback = shift;
         my $content = shift;
@@ -433,13 +414,17 @@ use strict;
 
     sub cleanup_attrs {
         my $hash = shift;
-
-        #* delete all strappings (__*)
-        map { delete $hash->{ $_ } } grep { substr($_, 0, 2) eq '__' } keys $hash->%*;
-
-        #* delete all keys whose value is not a string
-        map { delete $hash->{ $_ } } grep { $_ ne 'data' && ref $hash->{ $_ } ne '' } keys $hash->%*;
-
+        
+        map { delete $hash->{ $_ } } ('column_information',
+                                      'panel',
+                                      keys _sizes()->%*,
+                                      keys _button_contexts()->%*,
+                                      keys _panel_contexts()->%*,
+                                      keys _table_contexts()->%*,
+                                      keys _direction_contexts()->%*,
+                                      keys _menu_contexts()->%*);
+        # delete all attributes starting with __
+        map { delete $hash->{ $_ } } grep { substr $_, 0 => 2 eq '__' } keys $hash->%*;
         return $hash;
     }
 
@@ -468,13 +453,10 @@ use strict;
         return { map { ("__$_" => $_, $_ => $_) } qw/striped bordered hover condensed responsive/ };
     }
     sub _direction_contexts {
-        return { map { ("__$_" => $_, $_ => $_) } qw/right block/ };
+        return { map { ("__$_" => $_, $_ => $_) } qw/right/ };
     }
     sub _menu_contexts {
-        return { map { ("__$_" => undef, $_ => undef) } qw/caret/ };
-    }
-    sub _misc_contexts {
-        return { map { ("__$_" => $_, $_ => $_) } qw/active disabled/ };
+        return { map { ("__$_" => $_, $_ => $_) } qw/caret divider/ };
     }
 
     sub out {
